"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "useCheckboxProps", {
    enumerable: true,
    get: function() {
        return useCheckboxProps;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _reacthooks = require("@fluentui/react-hooks");
const _utils = require("../utils");
// https://react.fluentui.dev/?path=/docs/concepts-migration-from-v8-components-checkbox-migration--docs [Link of the fluent v9 migration guide]
// https://github.com/microsoft/fluentui/blob/master/packages/react/src/components/Checkbox/Checkbox.types.ts [Link of the fluent v8 checkbox types definition]
// https://github.com/microsoft/fluentui/blob/103b8977f8d5f8dd8c430bab46ff5308a2c76371/packages/react-components/react-checkbox/src/components/Checkbox/Checkbox.types.ts [Link of the fluent v9 checkbox types definition]
const CHECKBOX_PROPS_V8 = new Set([
    'ariaDescribedBy',
    'ariaLabel',
    'ariaLabelledBy',
    'ariaPositionInSet',
    'ariaSetSize',
    'boxSide',
    'checked',
    'checkmarkIconProps',
    'className',
    'componentRef',
    'defaultChecked',
    'defaultIndeterminate',
    'disabled',
    'indeterminate',
    'inputProps',
    'label',
    'name',
    'onChange',
    'onRenderLabel',
    'required',
    'styles',
    'theme',
    'title'
]);
const useCheckboxProps = (props)=>{
    const { ariaDescribedBy, ariaLabel, ariaLabelledBy, ariaPositionInSet, ariaSetSize, boxSide, checked: checkedV8, indeterminate, defaultChecked, defaultIndeterminate, disabled, inputProps, name, required, title, onChange: onChangeV8 } = props;
    const [checked, setChecked] = (0, _reacthooks.useControllableValue)(checkedV8, defaultChecked);
    const [mixed, setMixed] = _react.useState(indeterminate || defaultIndeterminate);
    const onChange = _react.useCallback((event, data)=>{
        let val = checked !== undefined ? data.checked : undefined;
        // Ensure the checkbox is controlled
        if (checked !== undefined) {
            if (mixed) {
                val = checkedV8 !== undefined ? checkedV8 : defaultChecked !== undefined ? defaultChecked : val;
            }
        }
        if (mixed) {
            setMixed(mixed && !indeterminate ? false : mixed);
        }
        setChecked(val);
        onChangeV8 === null || onChangeV8 === void 0 ? void 0 : onChangeV8(event, data.checked);
    }, [
        setChecked,
        checked,
        onChangeV8,
        mixed,
        indeterminate,
        checkedV8,
        defaultChecked
    ]);
    const v9Props = {
        checked: mixed ? 'mixed' : checked,
        defaultChecked: mixed ? 'mixed' : defaultChecked,
        labelPosition: boxSide === 'end' ? 'before' : 'after',
        disabled,
        required,
        title,
        name,
        onChange
    };
    return {
        ...inputProps,
        'aria-describedby': ariaDescribedBy,
        'aria-label': ariaLabel,
        'aria-labelledby': ariaLabelledBy,
        'aria-posinset': ariaPositionInSet,
        'aria-setsize': ariaSetSize,
        ...v9Props,
        ...(0, _utils.getHTMLAttributes)(props, CHECKBOX_PROPS_V8)
    };
};
